Module watcher

Module watcher 

File system watcher for automatic reloading

Watches project files for changes and notifies the server to reload.

Structs

FileWatcher
File system watcher that monitors project files for changes
WatcherConfig
Configuration for the file watcher

Enums

WatchEvent
Events from the file watcher